@@ -3,11 +3,23 @@
 if [[ "$1" == "--help"  ]]; then
     echo -e "Usage: $0"
     echo
-    echo -e "Supported environment variables: JICOFO_AUTH_PASSWORD, JICOFO_MAX_MEMORY, JAVA_SYS_PROPS."
+    echo -e "Supported environment variables: JICOFO_MAX_MEMORY, JAVA_SYS_PROPS."
     echo
     exit 1
 fi
 
+if [[ ! "$JAVA_SYS_PROPS" == *"-Dconfig.file="* ]]; then
+    if [[ -f /etc/jitsi/jicofo/jicofo.conf ]]; then
+        JAVA_SYS_PROPS="$JAVA_SYS_PROPS -Dconfig.file=/etc/jitsi/jicofo/jicofo.conf"
+    else
+        echo
+        echo "To run jicofo you need a configuration file. Use environment variable JAVA_SYS_PROPS."
+        echo "e.g. export JAVA_SYS_PROPS=\"-Dconfig.file=/etc/jitsi/jicofo/jicofo.conf\""
+        echo
+        exit 2
+    fi
+fi
+
 SCRIPT_DIR="$(dirname "$(readlink -f "$0")")"
 
 mainClass="org.jitsi.jicofo.Main"
